
/* huffdcmp.c */
/* A Huffman decompression program.                           */
/* This main module involves primarily file I/O               */

/* Author: Zach Tomaszewski */
/* Date: 10 Mar 2003        */


#include "huffdcmp.h"


int main(int argc, char* argv[]){

  FILE* huffFile;
  FILE* treeFile;
  FILE* outFile;
  Node* root;

  if (argc == 4) {

    /* make the tree */
    treeFile = fopen(argv[2], "rb");
    if (treeFile == NULL) {
      printf("Unable to open tree file: %s\n", argv[2]);
      return(1); //exit with error
    }
    root = readTree(treeFile);
    close(treeFile);

    /* decompress the .huf file */
    huffFile = fopen(argv[1], "rb");
    if (huffFile == NULL) {
      printf("Unable to open compressed file: %s\n", argv[1]);
      return(1); //exit with error
    }
    outFile = fopen(argv[3], "wb");
    if (outFile == NULL) {
      printf("Unable to open output file: %s\n", argv[3]);
      return(1); //exit with error
    }

    decompress(huffFile, root, outFile);

    close(huffFile);
    close(outFile);

    if (TREEINFO) { //request for tree info
       puts("Decoding tree info:");
       printf(" %d total leaves.  ", countLeaves(root));
       printf("0x%.2x is the largest byte value.\n", largestValue(root));
    }

  }else {
    usage();
  }  
  return 0;
}


/*
 Returns a usage message for this program to the screen
 */
void usage() {
  puts("");
  puts("Usage:");
  puts("\thuffdcmp [compressed file] [tree file] [output file]");
  puts("");
  puts("Example use: huffdcmp myfile.huf myfile.tre myfile.out");
  puts("");
}
